@@ -4,21 +4,28 @@ import (
 	"encoding/json"
 	"os"
 	"path/filepath"
-	"runtime"
 
-	"github.com/rkoesters/xdg/userdirs"
+	"github.com/adrg/xdg"
 	"github.com/shirou/gopsutil/disk"
+	varibale "github.com/yorukot/superfile/src/config"
 )
 
 // Return all sidebar directories
-func getDirectories(height int) []directory {
+func getDirectories() []directory {
 	directories := []directory{}
 
 	directories = append(directories, getWellKnownDirectories()...)
-	if height > 30 {
-		directories = append(directories, getPinnedDirectories()...)
-		directories = append(directories, getExternalMediaFolders()...)
-	}
+	directories = append(directories, directory{
+		// Just make sure no one owns the hard drive or directory named this path
+		location: "Pinned+-*/=?",
+	})
+	directories = append(directories, getPinnedDirectories()...)
+	directories = append(directories, directory{
+		// Just make sure no one owns the hard drive or directory named this path
+		location: "Disks+-*/=?",
+	})
+	directories = append(directories, getExternalMediaFolders()...)
+
 	return directories
 }
 
@@ -26,23 +33,14 @@ func getDirectories(height int) []directory {
 func getWellKnownDirectories() []directory {
 	directories := []directory{}
 	wellKnownDirectories := []directory{
-		{location: HomeDir, name: "󰋜 Home"},
-		{location: userdirs.Download, name: "󰏔 Downloads"},
-		{location: userdirs.Documents, name: "󰈙 Documents"},
-		{location: userdirs.Pictures, name: "󰋩 Pictures"},
-		{location: userdirs.Videos, name: "󰎁 Videos"},
-		{location: userdirs.Music, name: "♬ Music"},
-		{location: userdirs.Templates, name: "󰏢 Templates"},
-		{location: userdirs.PublicShare, name: " PublicShare"},
-	}
-
-	if runtime.GOOS == "darwin" {
-		wellKnownDirectories[1].location = HomeDir + "/Downloads/"
-		wellKnownDirectories[2].location = HomeDir + "/Documents/"
-		wellKnownDirectories[3].location = HomeDir + "/Pictures/"
-		wellKnownDirectories[4].location = HomeDir + "/Movies/"
-		wellKnownDirectories[5].location = HomeDir + "/Music/"
-		wellKnownDirectories[7].location = HomeDir + "/Public/"
+		{location: xdg.Home, name: "󰋜 Home"},
+		{location: xdg.UserDirs.Download, name: "󰏔 Downloads"},
+		{location: xdg.UserDirs.Documents, name: "󰈙 Documents"},
+		{location: xdg.UserDirs.Pictures, name: "󰋩 Pictures"},
+		{location: xdg.UserDirs.Videos, name: "󰎁 Videos"},
+		{location: xdg.UserDirs.Music, name: "♬ Music"},
+		{location: xdg.UserDirs.Templates, name: "󰏢 Templates"},
+		{location: xdg.UserDirs.PublicShare, name: " PublicShare"},
 	}
 
 	for _, dir := range wellKnownDirectories {
@@ -51,6 +49,7 @@ func getWellKnownDirectories() []directory {
 			directories = append(directories, dir)
 		}
 	}
+
 	return directories
 }
 
@@ -59,7 +58,7 @@ func getPinnedDirectories() []directory {
 	directories := []directory{}
 	var paths []string
 
-	jsonData, err := os.ReadFile(SuperFileDataDir + pinnedFile)
+	jsonData, err := os.ReadFile(varibale.PinnedFilea)
 	if err != nil {
 		outPutLog("Read superfile data error", err)
 	}
@@ -73,7 +72,7 @@ func getPinnedDirectories() []directory {
 	return directories
 }
 
-// Get external media directories 
+// Get external media directories
 func getExternalMediaFolders() (disks []directory) {
 	parts, err := disk.Partitions(true)
 
