@@ -1,58 +1,71 @@
 package internal
 
 import (
+	"bufio"
 	"fmt"
+	"image"
 	"os"
 	"path/filepath"
 	"sort"
 	"strconv"
 	"strings"
 
+	"github.com/alecthomas/chroma/lexers"
 	"github.com/charmbracelet/lipgloss"
+	"github.com/charmbracelet/x/exp/term/ansi"
+	"github.com/yorukot/ansichroma"
+	filepreview "github.com/yorukot/superfile/src/pkg/file_preview"
 )
 
 func sidebarRender(m model) string {
-	s := sidebarTitleStyle.Render("     Super File")
-	s += "\n\n"
+	if Config.SidebarWidth == 0 {
+		return ""
+	}
+	superfileTitle := sidebarTitleStyle.Render("     Super File")
+	superfileTitle = ansi.Truncate(superfileTitle, Config.SidebarWidth, "")
+	s := superfileTitle
+	s += "\n"
 
-	// Ugly shit workaround from hell code, made by @lescx
-	amountWellKnownDirectories := len(getWellKnownDirectories())
-	amountPinnedDirectories := len(getPinnedDirectories())
-	pinnedRendered := false
-	externalRendered := false
+	pinnedDivider := "\n" + sidebarTitleStyle.Render("󰐃 Pinned") + sidebarDividerStyle.Render(" ───────────") + "\n"
+	disksDivider := "\n" + sidebarTitleStyle.Render("󱇰 Disks") + sidebarDividerStyle.Render(" ────────────") + "\n"
+	disksDivider = ansi.Truncate(disksDivider, Config.SidebarWidth, "")
+	pinnedDivider = ansi.Truncate(pinnedDivider, Config.SidebarWidth, "")
 
-	pinnedDivider := "\n" + sidebarTitleStyle.Render("󰐃 Pinned") + sidebarDividerStyle.Render(" ───────────") + "\n\n"
-	disksDivider := "\n" + sidebarTitleStyle.Render("󱇰 Disks") + sidebarDividerStyle.Render(" ────────────") + "\n\n"
+	totalHeight := 2
+	for i := m.sidebarModel.renderIndex; i < len(m.sidebarModel.directories); i++ {
+		if totalHeight >= m.mainPanelHeight {
+			break
+		} else {
+			s += "\n"
+		}
 
-	for i, directory := range m.sidebarModel.directories {
-		if i == amountWellKnownDirectories && !pinnedRendered {
+		directory := m.sidebarModel.directories[i]
+
+		if directory.location == "Pinned+-*/=?" {
 			s += pinnedDivider
-			pinnedRendered = true
+			totalHeight += 3
+			continue
 		}
 
-		if i == amountPinnedDirectories+amountWellKnownDirectories && !externalRendered {
+		if directory.location == "Disks+-*/=?" {
+			if m.mainPanelHeight-totalHeight <= 2 {
+				break
+			}
 			s += disksDivider
-			externalRendered = true
+			totalHeight += 3
+			continue
 		}
+
+		totalHeight++
 		cursor := " "
 		if m.sidebarModel.cursor == i && m.focusPanel == sidebarFocus {
 			cursor = ""
 		}
-		if directory.location == m.fileModel.filePanels[m.filePanelFocusIndex].location {
-			s += filePanelCursorStyle.Render(cursor) + sidebarSelectedStyle.Render(" "+truncateText(directory.name, sidebarWidth-2)) + "\n"
-		} else {
-			s += filePanelCursorStyle.Render(cursor) + sidebarStyle.Render(" "+truncateText(directory.name, sidebarWidth-2)) + "\n"
-		}
-	}
 
-	// In case no pinned directories or external drives are pinned,
-	// list menu item at the bottom
-	if m.fullHeight > 30 {
-		if !pinnedRendered {
-			s += pinnedDivider
-		}
-		if !externalRendered {
-			s += disksDivider
+		if directory.location == m.fileModel.filePanels[m.filePanelFocusIndex].location {
+			s += filePanelCursorStyle.Render(cursor+" ") + sidebarSelectedStyle.Render(truncateText(directory.name, Config.SidebarWidth-2, "..."))
+		} else {
+			s += filePanelCursorStyle.Render(cursor+" ") + sidebarStyle.Render(truncateText(directory.name, Config.SidebarWidth-2, "..."))
 		}
 	}
 
@@ -71,12 +84,16 @@ func filePanelRender(m model) string {
 		}
 		m.fileModel.filePanels[i] = filePanel
 
-		f[i] += filePanelTopDirectoryIconStyle.Render("   ") + filePanelTopPathStyle.Render(truncateTextBeginning(filePanel.location, m.fileModel.width-4)) + "\n"
+		f[i] += filePanelTopDirectoryIconStyle.Render("   ") + filePanelTopPathStyle.Render(truncateTextBeginning(filePanel.location, m.fileModel.width-4, "...")) + "\n"
 		filePanelWidth := 0
 		footerBorderWidth := 0
 
-		if (m.fullWidth-sidebarWidth-(4+(len(m.fileModel.filePanels)-1)*2))%len(m.fileModel.filePanels) != 0 && i == len(m.fileModel.filePanels)-1 {
-			filePanelWidth = (m.fileModel.width + (m.fullWidth-sidebarWidth-(4+(len(m.fileModel.filePanels)-1)*2))%len(m.fileModel.filePanels))
+		if (m.fullWidth-Config.SidebarWidth-(4+(len(m.fileModel.filePanels)-1)*2))%len(m.fileModel.filePanels) != 0 && i == len(m.fileModel.filePanels)-1 {
+			if m.fileModel.filePreview.open {
+				filePanelWidth = m.fileModel.width
+			} else {
+				filePanelWidth = (m.fileModel.width + (m.fullWidth-Config.SidebarWidth-(4+(len(m.fileModel.filePanels)-1)*2))%len(m.fileModel.filePanels))
+			}
 			footerBorderWidth = m.fileModel.width + 7
 		} else {
 			filePanelWidth = m.fileModel.width
@@ -121,7 +138,7 @@ func filePanelRender(m model) string {
 		}
 	}
 
-	// file panel render togther
+	// file panel render together
 	filePanelRender := ""
 	for _, f := range f {
 		filePanelRender = lipgloss.JoinHorizontal(lipgloss.Top, filePanelRender, f)
@@ -188,7 +205,7 @@ func processBarRender(m model) string {
 			symbol = processCancelStyle.Render("")
 		}
 
-		processRender += cursor + footerStyle.Render(truncateText(process.name, footerWidth(m.fullWidth)-7)+" ") + symbol + "\n"
+		processRender += cursor + footerStyle.Render(truncateText(process.name, footerWidth(m.fullWidth)-7, "...")+" ") + symbol + "\n"
 		if renderTimes == 2 {
 			processRender += cursor + process.progress.ViewAs(float64(process.done)/float64(process.total)) + ""
 		} else if footerHeight < 14 && renderTimes == 1 {
@@ -209,7 +226,7 @@ func processBarRender(m model) string {
 		courseNumber = m.processBarModel.cursor + 1
 	}
 	bottomBorder := generateFooterBorder(fmt.Sprintf("%s/%s", strconv.Itoa(courseNumber), strconv.Itoa(len(m.processBarModel.processList))), footerWidth(m.fullWidth)-3)
-	processRender = procsssBarBoarder(bottomElementHight(footerHeight), footerWidth(m.fullWidth), bottomBorder, m.focusPanel).Render(processRender)
+	processRender = procsssBarBoarder(bottomElementHeight(footerHeight), footerWidth(m.fullWidth), bottomBorder, m.focusPanel).Render(processRender)
 
 	return processRender
 }
@@ -252,20 +269,20 @@ func metadataRender(m model) string {
 		sprintfLength = valueLength
 	}
 
-	for i := m.fileMetaData.renderIndex; i < bottomElementHight(footerHeight)+m.fileMetaData.renderIndex && i < len(m.fileMetaData.metaData); i++ {
+	for i := m.fileMetaData.renderIndex; i < bottomElementHeight(footerHeight)+m.fileMetaData.renderIndex && i < len(m.fileMetaData.metaData); i++ {
 		if i != m.fileMetaData.renderIndex {
 			metaDataBar += "\n"
 		}
-		data := truncateMiddleText(m.fileMetaData.metaData[i][1], valueLength)
+		data := truncateMiddleText(m.fileMetaData.metaData[i][1], valueLength, "...")
 		metadataName := m.fileMetaData.metaData[i][0]
 		if footerWidth(m.fullWidth)-maxKeyLength-3 < footerWidth(m.fullWidth)/2 {
-			metadataName = truncateMiddleText(m.fileMetaData.metaData[i][0], valueLength)
+			metadataName = truncateMiddleText(m.fileMetaData.metaData[i][0], valueLength, "...")
 		}
 		metaDataBar += fmt.Sprintf("%-*s %s", sprintfLength, metadataName, data)
 
 	}
 	bottomBorder := generateFooterBorder(fmt.Sprintf("%s/%s", strconv.Itoa(m.fileMetaData.renderIndex+1), strconv.Itoa(len(m.fileMetaData.metaData))), footerWidth(m.fullWidth)-3)
-	metaDataBar = metadataBoarder(bottomElementHight(footerHeight), footerWidth(m.fullWidth), bottomBorder, m.focusPanel).Render(metaDataBar)
+	metaDataBar = metadataBoarder(bottomElementHeight(footerHeight), footerWidth(m.fullWidth), bottomBorder, m.focusPanel).Render(metaDataBar)
 
 	return metaDataBar
 }
@@ -277,8 +294,8 @@ func clipboardRender(m model) string {
 	if len(m.copyItems.items) == 0 {
 		clipboardRender += "\n   No content in clipboard"
 	} else {
-		for i := 0; i < len(m.copyItems.items) && i < bottomElementHight(footerHeight); i++ {
-			if i == bottomElementHight(footerHeight)-1 {
+		for i := 0; i < len(m.copyItems.items) && i < bottomElementHeight(footerHeight); i++ {
+			if i == bottomElementHeight(footerHeight)-1 {
 				clipboardRender += strconv.Itoa(len(m.copyItems.items)-i+1) + " item left...."
 			} else {
 				fileInfo, err := os.Stat(m.copyItems.items[i])
@@ -301,7 +318,7 @@ func clipboardRender(m model) string {
 	} else {
 		bottomWidth = footerWidth(m.fullWidth)
 	}
-	clipboardRender = clipboardBoarder(bottomElementHight(footerHeight), bottomWidth, Config.BorderBottom).Render(clipboardRender)
+	clipboardRender = clipboardBoarder(bottomElementHeight(footerHeight), bottomWidth, Config.BorderBottom).Render(clipboardRender)
 
 	return clipboardRender
 }
@@ -330,48 +347,63 @@ func terminalSizeWarnRender(m model) string {
 		heightString + terminalCorrectSize.Render(minimumHeightString))
 }
 
-func typineModalRender(m model) string {
-	if m.typingModal.itemType == newFile {
-		previewPath := filepath.Join(m.typingModal.location, m.typingModal.textInput.Value())
+func terminalSizeWarnAfterFirstRender(m model) string {
+	minimumWidthInt := Config.SidebarWidth + 20*len(m.fileModel.filePanels) + 20 - 1
+	minimumWidthString := strconv.Itoa(minimumWidthInt)
+	fullWidthString := strconv.Itoa(m.fullWidth)
+	fullHeightString := strconv.Itoa(m.fullHeight)
+	minimumHeightString := strconv.Itoa(minimumHeight)
 
-		fileLocation := filePanelTopDirectoryIconStyle.Render("   ") +
-			filePanelTopPathStyle.Render(truncateTextBeginning(previewPath, modalWidth-4)) + "\n"
-
-		confirm := modalConfirm.Render(" (" + hotkeys.Confirm[0] + ") New File ")
-		cancel := modalCancel.Render(" (" + hotkeys.Cancel[0] + ") Cancel ")
-
-		tip := confirm +
-			lipgloss.NewStyle().Background(modalBGColor).Render("           ") +
-			cancel
-
-		return modalBorderStyle(modalHeight, modalWidth).Render(fileLocation + "\n" + m.typingModal.textInput.View() + "\n\n" + tip)
-	} else {
-		previewPath := filepath.Join(m.typingModal.location, m.typingModal.textInput.Value())
-
-		fileLocation := filePanelTopDirectoryIconStyle.Render("   ") +
-			filePanelTopPathStyle.Render(truncateTextBeginning(previewPath, modalWidth-4)) + "\n"
-
-		confirm := modalConfirm.Render(" (" + hotkeys.Confirm[0] + ") New Folder ")
-		cancel := modalCancel.Render(" (" + hotkeys.Cancel[0] + ") Cancel ")
-		tip := confirm + lipgloss.NewStyle().Background(modalBGColor).Render("           ") + cancel
-		return modalBorderStyle(modalHeight, modalWidth).Render(fileLocation + "\n" + m.typingModal.textInput.View() + "\n\n" + tip)
+	if m.fullHeight < minimumHeight {
+		fullHeightString = terminalTooSmall.Render(fullHeightString)
 	}
+	if m.fullWidth < minimumWidthInt {
+		fullWidthString = terminalTooSmall.Render(fullWidthString)
+	}
+	fullHeightString = terminalCorrectSize.Render(fullHeightString)
+	fullWidthString = terminalCorrectSize.Render(fullWidthString)
+
+	heightString := mainStyle.Render(" Height = ")
+	return fullScreenStyle(m.fullHeight, m.fullWidth).Render(`You change your terminal size too small:` + "\n" +
+		"Width = " + fullWidthString +
+		heightString + fullHeightString + "\n\n" +
+
+		"Needed for current config:" + "\n" +
+		"Width = " + terminalCorrectSize.Render(minimumWidthString) +
+		heightString + terminalCorrectSize.Render(minimumHeightString))
+}
+
+func typineModalRender(m model) string {
+	previewPath := m.typingModal.location + "/" + m.typingModal.textInput.Value()
+
+	fileLocation := filePanelTopDirectoryIconStyle.Render("   ") +
+		filePanelTopPathStyle.Render(truncateTextBeginning(previewPath, modalWidth-4, "...")) + "\n"
+
+	confirm := modalConfirm.Render(" (" + hotkeys.ConfirmTyping[0] + ") Create ")
+	cancel := modalCancel.Render(" (" + hotkeys.CancelTyping[0] + ") Cancel ")
+
+	tip := confirm +
+		lipgloss.NewStyle().Background(modalBGColor).Render("           ") +
+		cancel
+
+	return modalBorderStyle(modalHeight, modalWidth).Render(fileLocation + "\n" + m.typingModal.textInput.View() + "\n\n" + tip)
 }
 
 func introduceModalRender(m model) string {
 	title := sidebarTitleStyle.Render(" Thanks for use superfile!!") + modalStyle.Render("\n You can read the following information before starting to use it!")
-	subOne := sidebarTitleStyle.Render("  (1)") + modalStyle.Render(" If this is your first time, make sure you read:\n      https://github.com/MHNightCat/superfile/wiki/Tutorial")
+	vimUserWarn := processErrorStyle.Render("  ** Very importantly ** If you are a Vim/Nvim user, go to:\n  https://superfile.netlify.app/configure/custom-hotkeys/ to change your hotkey settings!")
+	subOne := sidebarTitleStyle.Render("  (1)") + modalStyle.Render(" If this is your first time, make sure you read:\n      https://superfile.netlify.app/getting-started/tutorial/")
 	subTwo := sidebarTitleStyle.Render("  (2)") + modalStyle.Render(" If you forget the relevant keys during use,\n      you can press \"?\" (shift+/) at any time to query the keys!")
-	subThree := sidebarTitleStyle.Render("  (3)") + modalStyle.Render(" For more customization you can refer to:\n      https://github.com/MHNightCat/superfile/wiki")
-	subFour := sidebarTitleStyle.Render("  (4)") + modalStyle.Render(" Thank you again for using superfile.\n      If you have any questions, please feel free to ask at:\n      https://github.com/MHNightCat/superfile\n      Of course, you can always open a new issue to share your idea \n      or report a bug!")
-	return firstUseModal(m.helpMenu.height, m.helpMenu.width).Render(title + "\n\n" + subOne + "\n\n" + subTwo + "\n\n" + subThree + "\n\n" + subFour + "\n\n")
+	subThree := sidebarTitleStyle.Render("  (3)") + modalStyle.Render(" For more customization you can refer to:\n      https://superfile.netlify.app/")
+	subFour := sidebarTitleStyle.Render("  (4)") + modalStyle.Render(" Thank you again for using superfile.\n      If you have any questions, please feel free to ask at:\n      https://github.com/yorukot/superfile\n      Of course, you can always open a new issue to share your idea \n      or report a bug!")
+	return firstUseModal(m.helpMenu.height, m.helpMenu.width).Render(title + "\n\n" + vimUserWarn + "\n\n" + subOne + "\n\n" + subTwo + "\n\n" + subThree + "\n\n" + subFour + "\n\n")
 }
 
 func warnModalRender(m model) string {
 	title := m.warnModal.title
 	content := m.warnModal.content
-	confirm := modalCancel.Render(" (" + hotkeys.Confirm[0] + ") Confirm ")
-	cancel := modalCancel.Render(" (" + hotkeys.Cancel[0] + ") Cancel ")
+	confirm := modalConfirm.Render(" (" + hotkeys.Confirm[0] + ") Confirm ")
+	cancel := modalCancel.Render(" (" + hotkeys.Quit[0] + ") Cancel ")
 	tip := confirm + lipgloss.NewStyle().Background(modalBGColor).Render("           ") + cancel
 	return modalBorderStyle(modalHeight, modalWidth).Render(title + "\n\n" + content + "\n\n" + tip)
 }
@@ -420,6 +452,7 @@ func helpMenuRender(m model) string {
 			renderHotkeyLength = len(helpMenuHotkeyStyle.Render(hotkey))
 		}
 	}
+
 	for i := m.helpMenu.renderIndex; i < m.helpMenu.height+m.helpMenu.renderIndex && i < len(m.helpMenu.data); i++ {
 
 		if i != m.helpMenu.renderIndex {
@@ -432,7 +465,7 @@ func helpMenuRender(m model) string {
 		}
 
 		hotkey := ""
-		description := truncateText(m.helpMenu.data[i].description, valueLength)
+		description := truncateText(m.helpMenu.data[i].description, valueLength, "...")
 		if m.helpMenu.data[i].hotkey[1] == "" {
 			hotkey = m.helpMenu.data[i].hotkey[0]
 		} else {
@@ -449,3 +482,122 @@ func helpMenuRender(m model) string {
 
 	return helpMenuModalBorderStyle(m.helpMenu.height, m.helpMenu.width, bottomBorder).Render(helpMenuContent)
 }
+
+func filePreviewPanelRender(m model) string {
+	previewLine := m.mainPanelHeight + 2
+	m.fileModel.filePreview.width += m.fullWidth - Config.SidebarWidth - m.fileModel.filePreview.width - ((m.fileModel.width + 2) * len(m.fileModel.filePanels)) - 2
+
+	panel := m.fileModel.filePanels[m.filePanelFocusIndex]
+	box := filePreviewBox(previewLine, m.fileModel.filePreview.width)
+
+	if len(panel.element) == 0 {
+		return box.Render("\n ---  No content to preview ---")
+	}
+
+	itemPath := panel.element[panel.cursor].location
+
+	fileInfo, err := os.Stat(itemPath)
+	if err != nil {
+		outPutLog("error get file info", err)
+		return box.Render("\n ---  Error get file info ---")
+	}
+	if fileInfo.IsDir() {
+		directoryContent := ""
+		dirPath := itemPath
+
+		files, err := os.ReadDir(dirPath)
+		if err != nil {
+			outPutLog("Error render directory preview", err)
+			return box.Render("\n ---  Error render directory preview ---")
+		}
+
+		if len(files) == 0 {
+			return box.Render("\n --- empty ---")
+		}
+
+		sort.Slice(files, func(i, j int) bool {
+			if files[i].IsDir() && !files[j].IsDir() {
+				return true
+			}
+			if !files[i].IsDir() && files[j].IsDir() {
+				return false
+			}
+			return files[i].Name() < files[j].Name()
+		})
+
+		for i := 0; i < previewLine && i < len(files); i++ {
+			file := files[i]
+			directoryContent += prettierDirectoryPreviewName(file.Name(), file.IsDir(), lipgloss.Color(theme.FilePanelBG))
+			if i != previewLine-1 && i != len(files)-1 {
+				directoryContent += "\n"
+			}
+		}
+		directoryContent = checkAndTruncateLineLengths(directoryContent, m.fileModel.filePreview.width)
+		return box.Render(directoryContent)
+	}
+
+	if isImageFile(itemPath) {
+		ansiRender, err := filepreview.ImagePreview(itemPath, m.fileModel.filePreview.width, previewLine, theme.FilePanelBG)
+		if err == image.ErrFormat {
+			return box.Render("\n ---  Unsupported image formats ---")
+		}
+
+		if err != nil {
+			outPutLog("Error covernt image to ansi", err)
+			return box.Render("\n ---  Error covernt image to ansi ---")
+		}
+
+		return box.AlignVertical(lipgloss.Center).AlignHorizontal(lipgloss.Center).Render(ansiRender)
+	}
+
+	format := lexers.Match(filepath.Base(itemPath))
+	if format != nil {
+		codeHighlight, err := ansichroma.HighlightFromFile(itemPath, previewLine, theme.CodeSyntaxHighlightTheme, theme.FilePanelBG)
+
+		if err != nil {
+			outPutLog("Error render code highlight", err)
+			return box.Render("\n ---  Error render code highlight ---")
+		}
+		if codeHighlight == "" {
+			return box.Render("\n --- empty ---")
+		}
+		codeHighlight = checkAndTruncateLineLengths(codeHighlight, m.fileModel.filePreview.width)
+		return box.Render(codeHighlight)
+	} else {
+		textFile, err := isTextFile(itemPath)
+		if err != nil {
+			outPutLog("Error check text file", err)
+		}
+		if textFile {
+			var fileContent string
+			file, err := os.Open(itemPath)
+			if err != nil {
+				outPutLog(err)
+				return box.Render("\n ---  Error open file ---")
+			}
+			defer file.Close()
+
+			scanner := bufio.NewScanner(file)
+			lineCount := 0
+
+			for scanner.Scan() {
+				fileContent += scanner.Text() + "\n"
+				lineCount++
+				if previewLine > 0 && lineCount >= previewLine {
+					break
+				}
+			}
+
+			if err := scanner.Err(); err != nil {
+				outPutLog(err)
+				return box.Render("\n ---  Error open file ---")
+			}
+
+			textContent := checkAndTruncateLineLengths(string(fileContent), m.fileModel.filePreview.width)
+
+			return box.Render(textContent)
+		}
+	}
+
+	return box.Render("\n ---  Unsupported formats ---")
+}
